#
# spec file for package dirmngr
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dirmngr
Version:        1.1.1
Release:        8.1
Summary:        A Client for Managing and Downloading CRLs
License:        GPL-3.0+
Group:          Productivity/Networking/LDAP/Utilities
Url:            http://www.gnupg.org/aegypten/
Source:         ftp://ftp.gnupg.org/gcrypt/dirmngr/%{name}-%{version}.tar.bz2
Source1:        LICENSE.README
Source2:        dirmngr.conf
Source3:        ldapservers.conf
Source4:        dirmngrtmp.conf
Source5:        dirmngr.logrotate
Patch0:         dirmngr-1.0.2-optflags.patch
Patch1:         dirmngr-initialize_pth.patch
BuildRequires:  automake
BuildRequires:  libassuan-devel >= 2.0.0
BuildRequires:  libgcrypt-devel >= 1.4.0
BuildRequires:  libgpg-error-devel >= 1.4
BuildRequires:  libksba-devel >= 1.0.2
BuildRequires:  libpth-devel >= 1.3.7
BuildRequires:  openldap2-devel
Requires:       openssl
Requires(pre):  %{install_info_prereq}
Recommends:     %{name}-lang

%description
Dirmngr is a client for managing and downloading certificate revocation
lists (CRLs) for X509 certificates and for downloading the certificates
themselves.

%lang_package

%prep
%setup -q
%patch0
%patch1
cp %{SOURCE1} .

%build
NOCONFIGURE=1 ./autogen.sh
#export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED"
%configure \
	--libexecdir=%{_libexecdir}/dirmngr \
    --docdir=%{_defaultdocdir}/%{name}
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
%find_lang %{name}

# Directories for daemon mode
mkdir -p %{buildroot}%{_sysconfdir}/dirmngr/trusted-certs
mkdir -p %{buildroot}%{_var}/cache/dirmngr/crls.d
mkdir -p %{buildroot}%{_var}/lib/dirmngr/extra-certs
mkdir -p %{buildroot}%{_var}/log/dirmngr
mkdir -p %{buildroot}%{_var}/run/dirmngr

install -p -m644 %{SOURCE2} %{SOURCE3} %{buildroot}%{_sysconfdir}/dirmngr/
install -p -m644 -D %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/dirmngr.conf
install -p -m644 -D %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/dirmngr

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README LICENSE.README
%{_defaultdocdir}/%{name}
%{_bindir}/*
%{_infodir}/dirmngr*
%{_mandir}/man1/dirmngr*.1.gz
%{_libexecdir}/dirmngr

# Daemon mode
%dir %{_sysconfdir}/dirmngr
%dir %{_sysconfdir}/dirmngr/trusted-certs
%config(noreplace) %{_sysconfdir}/dirmngr/*.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/*
%{_prefix}/lib/tmpfiles.d/*.conf
%{_var}/cache/dirmngr/
%{_var}/lib/dirmngr/
%{_var}/log/dirmngr/
%dir %{_var}/run/dirmngr

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Tue Sep 13 2016 pjanouch@suse.de
- add the required files to make daemon mode work (bsc#994794)
  * add dirmngr.conf
  * add dirmngr.logrotate
  * add dirmngrtmp.conf
  * add ldapservers.conf
* Mon Oct 20 2014 vcizek@suse.com
- initialize pth with libgcrypt > 1.6.0 (bnc#901845)
  * added dirmngr-initialize_pth.patch
  * http://bugs.gnupg.org/gnupg/issue1590
- spec-cleaned .spec
* Tue Dec 17 2013 p.drouand@gmail.com
- Update to version 1.1.1
  + Fixes for building with newer mingw32 versions.
- Remove dirmngr-GPLv3.patch and dirmngr-GPLv3.patch; merged and/or
  fixed on upstream release
- Subpackage locales
* Thu Dec  1 2011 puzel@suse.com
- fix license in specfile (bnc#734177)
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Aug 29 2011 crrodriguez@opensuse.org
- Add missing -llber where relevant.
* Thu Nov 18 2010 puzel@novell.com
- upstream relicensed to GPLv3 (bnc#652989)
- add dirmngr-GPLv3.patch
- add LICENSE.README
* Tue Aug 17 2010 puzel@novell.com
- update to dirmngr-1.1.0
  - only bumps version number
* Wed Apr 14 2010 chris@computersalat.de
- fix deps
  * added
    o libgpg-error-devel >= 1.4
  * updated
    o libassuan-devel >= 2.0.0
    o pth / libpth-devel >= 1.3.7
* Tue Apr  6 2010 puzel@novell.com
- update to dirmngr-1.1.0rc1
  * Fixed a resource problem with LDAP CRLs.
  * Fixed a bad EOF detection with HTTP CRLs.
  * Made "dirmngr-client --url --load-crl URL" work.
  * New option --ignore-cert-extension.
* Fri Dec 25 2009 jengelh@medozas.de
- enable parallel build
* Wed Jun 17 2009 puzel@suse.cz
- update to dirmngr-1.0.3
  * Client based trust anchors are now supported.
  * Configured certificates with the suffix ".der" are now also used.
  * Libgcrypt 1.4 is now required.
- drop obsoleted db-devel build dependency
* Thu Jun 11 2009 puzel@suse.cz
- change BuildRequires: (pth-devel -> libpth-devel)
* Mon Jun  1 2009 puzel@suse.cz
- BuildRequires: pth-devel
* Mon Aug  4 2008 puzel@suse.cz
- update to 1.0.2
  * new option --url for the LOOKUP command and dirmngr-client
  * the LOOKUP command does now also consults the local cache
  - new option --cache-only for it and --local for dirmngr-client
  * port to Windows completed
  * improved certificate chain construction
  * support loading of PEM encoded CRLs via HTTP.
- install some certificates to %%docdir/dirmngr/examples
- removed unnecessary krb5 dependency
- use %%makeinstall macro
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
- fix info-files-without-install-info-* errors
- update to version 1.0.1
  * The option --ocsp-signer may now take a filename to allow several
  certificates to be valid signers for the default responder.
  * New option --ocsp-max-period and improved the OCSP time checks.
  * New option --force-default-signer for dirmngr-client.
* Mon Jul 30 2007 ltinkl@suse.cz
- updated to 1.0.0
  * Removed included gettext.  We now require the system to provide a
    suitable installation.
* Thu Jul 26 2007 sbrabec@suse.cz
- Build with libassuan-devel.
* Wed Mar 14 2007 ltinkl@suse.cz
- update to 0.9.7
- remove builtin pth copy
- package man pages
- fix build
* Fri Jun 30 2006 pnemec@suse.cz
- updated to version 0.9.5
  improved diagnostic
  better CRL handling
  see NEWS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Sep 25 2005 ro@suse.de
- added LDAP_DEPRECATED to CFLAGS
* Mon Jul 11 2005 postadal@suse.cz
- updated to version 0.9.2
- removed obsoleted patch 64bit.diff
- link against libpth 2.0.4 staticaly, hopefully we can convert
  this to a native thread implementation later.
* Mon Jan 24 2005 ro@suse.de
- find ldap on lib64
* Wed Jan 12 2005 postadal@suse.cz
- updated to version 0.5.65.65.65.65.6
- removed obsoleted patch libldap.diff
* Fri Jul 23 2004 schwab@suse.de
- Fix neededforbuild.
- Fix 64-bit bugs.
* Tue Jul 13 2004 adrian@suse.de
- update to version 0.5.5
* Fri Feb 20 2004 mmj@suse.de
- Add libgpg-error to #nfb
- Adapt some functions to the new libgcrypt version
* Wed Feb 18 2004 kukuk@suse.de
- Remove package name requires, RPM can handle this better
- Don't build with libpth
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Mon Jun  2 2003 mc@suse.de
- switch to version 0.4.5. This release fixes these Bugs:
  * --flushing cache does not work
  * dirmngr chokes on *
  * dirmngr lookup loop
  * only searching first ldap entry
* Sun May 11 2003 ro@suse.de
- fix build with db-4.1
* Fri Feb 21 2003 mc@suse.de
- fixed lib64 ldap Problem
* Fri Feb 21 2003 mc@suse.de
- initial Version 0.4.4
- add patch to use db-4
